/* This do file creates population pyramids for the Newfoundland and Labrador rural secretariates based on NL Department of Finance-collected forcast data
Data located at: http://www.economics.gov.nl.ca/pop-projections.asp?dd=Popbyrsr 

Queries regarding this do file to:
Dr. Matthew Kerby
School of Political Studies
University of Ottawa
Ottawa, ON, Canada
mkerby@uottawa.ca */

version 12
clear 
clear matrix 
capture log close 
set more off 
* set scheme lean2
set scheme s2color


local data "/Users/kerbym/Dropbox/2013_NL_Population_Projections/data/"
local rrsr1 ""RSR (1) - Labrador Region""
local rrsr2 ""RSR (2) - St. Anthony - Port au Choix Region""
local newrsr "rrsr1 rrsr2"




cd "/Users/kerbym/Dropbox/2013_NL_Population_Projections"


* Hamilton's population pyramid data example
* use `data'greenpop1.dta
* stop
* clear







* foreach rsr in rsr1 rsr2 rsr3 rsr4 rsr5 rsr6 rsr7 rsr8 rsr9 { 
* foreach rsr in rsr1 rsr2  { 




/* Change rsr number as needed */
import excel "/Users/kerbym/Dropbox/2013_NL_Population_Projections/data/Popbyrsrmedium-web.xls", sheet("rsr9")





gen title = A in 1
gen scenario = A in 2
gen subtitle = A in 3
gen yearrange = A in 4
gen rsr = A in 5


foreach name in title scenario subtitle yearrange rsr {
	replace `name' = `name'[_n-1] if `name' == "" 
	}
drop in 1/6

gen sex = B if A == ""
replace sex = sex[_n-1] if sex == ""
drop if sex == "Total"
rename (B-W) v#, addnumber
drop v21 v22
rename A year
drop v1 
drop in 1

replace year = year+"_male" if sex == "Males"
replace year = year+"_female" if sex == "Females"
drop if year == "_male" | year == "_female"



reshape long v, i(year) j(agerange)
destring year,i("_male" "_female") replace
destring v, replace

rename agerange age /* now I need to label it */
gen males = v if sex == "Males"
gen females = v if sex == "Females"
sort year age sex
by year age: replace females = females[_n-1] if females == .
gsort year age -sex
by year age: replace males = males[_n-1] if males == .
duplicates drop year age, force
drop v sex

gen negmales = -males
gen negfemales = -females


egen max_MF = rowmax(males females)
gen max_MF2 = max_MF+max_MF*.2
bysort year: egen max_MF3 = max(max_MF2)




* gen malGRAY = -(4000-males) if (age >=6 & age<10) | (age>=14 & age < 18)
* gen femGRAY = (4000-females) if (age >=6 & age<10) | (age>=14 & age < 18)

gen malGRAY = -(12000-males) if (age >=6 & age<10) | (age>=14 & age < 18)
gen femGRAY = (12000-females) if (age >=6 & age<10) | (age>=14 & age < 18)




foreach num of numlist 1986/2026 {






/* Change graph title and graph label as needed; graph design from from Lawrence Hamilton, Statistics with Stata 10, pp. 131-3 */
graph hbar (sum) negmales females malGRAY femGRAY if year == `num',  title(Population Projections Newfoundland and Labrador) subtitle("RSR (9) - Avalon Peninsula Region") ytitle("Population by Five Year Age Groups: Males (left) and Females (Right)")  /* ylabel(-12000(2000)12000) */ ylabel(-12000 "12000" -9000 "9000" -6000 "6000" -3000 "3000" 0 3000 6000 9000 12000) over(age, descending gap(0) label(nolabel)) stack bargap(0) bar(1, color(gs8)) bar(2, color(gs3)) bar(3, color(gs14)) bar(4, color(gs14)) text(-10000 11 "Age 0 to 19") text(-10000 33 "Age 20 to 39") text(-10000 53 "Age 40 to 59") text(-10000 74 "Age 60 to 79") text(-10000 95 "Age 80+") text(10000 97 "`num'", size(large)) legend(off) note("Source: http://www.economics.gov.nl.ca/POP-default.asp") name("rsr9_`num'", replace)

* graph export "/Users/kerbym/Desktop/scratch_folder/nl_pop/rs09/rsr9_`num'.png", replace 
}



 